# package_name

Description. 
The package basic ops Calculator is used to:
	Operations 
		-Basic
			-sum, subtractions, division, multiplication, raise a number and make n square of a number
		-Advanced
			-logarithm, natural logarithm exponential e base

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install basic_ops_calculator

```bash
pip install basic_ops_calculator
```

## Usage

```python
from basic_ops_calculator.operations import basic
basic.make_sum(a, b)
```

## Author
Marcelo L Valerio

## License
[MIT](https://choosealicense.com/licenses/mit/)